/*
 * Lixie FPS Test
 * by Connor Nishijima
 * 
 * This sketch will count from 0 to MAX_NUMBER,
 * writing each number to your Lixie Displays.
 * 
 * The time it takes to do this in microseconds
 * will be divided by MAX_NUMBER, giving the
 * microseconds each write took. Dividing
 * 1,000,000 by this value gives the FPS of your
 * microcontroller.
 * 
 * The higher MAX_NUMBER is, the more accurate
 * your results will be.
 */

/* !!! IMPORTANT !!!
 * The Lixie-Particle library relies on [the FastLED2 library from Daniel Garcia] available on the Particle Web IDE!
 *
 * 1. Open Libraries and search for "FastLED2" and select it from the resulting list of libraries
 * 2. Click on "INCLUDE IN PROJECT" and select the Lixie-Particle example you had selected above from your list of applications
 * 3. ERASE the lines added at the top of the application file which look like this:
 *
 *	// This #include statement was automatically added by the Particle IDE.
 *	#include <FastLED2.h>
 *
 */

#include "Arduino.h"
#include <Lixie-Particle.h> // Include Lixie Library

SYSTEM_MODE(SEMI_AUTOMATIC);
SYSTEM_THREAD(ENABLED);

#define DATA_PIN   D5
#define NUM_LIXIES 4
Lixie lix(DATA_PIN, NUM_LIXIES);

void checkFPS();

uint32_t MAX_NUMBER = 500; // Number of times to write to the displays

void setup() {
  Serial.begin(115200);  
  delay(5000);
  Serial.println("Starting up...");
  
  lix.begin(); // Initialize LEDs
}

void loop() {
  checkFPS();
  delay(3000);
}

void checkFPS(){
  Serial.println("Starting Lixie FPS test...");
  lix.color(255, 255, 0); // Yellow while testing

  unsigned long tStart = micros(); // Start time
  for(uint32_t count = 0; count < MAX_NUMBER; count++) {
    lix.write(count);
  }
  unsigned long tEnd = micros(); // End time
  
  int FPS = 1000000 / ((tEnd - tStart) / MAX_NUMBER); // Get FPS by how many microseconds all writes took
  lix.color(0, 255, 0); // Green when done
  
  Serial.print("Done!\nFPS is: ");
  Serial.println(FPS);
  
  // Blink FPS result
  for(byte i = 0; i < 4; i++){
    lix.clear();
    delay(250);
    lix.write(FPS);
    delay(250);
  }
}
